#!/usr/bin/env python
# -*- encoding: utf-8 -*-
# IDE: PyCharm 2017.2.4
# Author: Dajiang Ren<rendajiang@gagogroup.com>
# Created on 2018-10-17


FIELD_MAPPINGS = {
    'file_type': ['文件类型', ''],
    'no_data': ['空像素', ''],
    'coordinate_system': ['坐标系统', ''],
    'extent': ['坐标范围', ''],
    'bias': ['坐标偏移算法', ''],
    'data_type': ['像元数据类型', ''],
    'lines': ['栅格数据列数', ''],
    'rows': ['栅格数据行数', ''],
    'resolution': ['分辨率', ''],
    'compression': ['压缩算法', ''],
    'geometry_type': ['几何类型', ''],
}
